Class TemplatesServiceClient

java.lang.Object
com.google.dataflow.v1beta3.TemplatesServiceClient
All Implemented Interfaces:
BackgroundResource, AutoCloseable

@BetaApi @Generated("by gapic-generator-java") public class TemplatesServiceClient extends Object implements BackgroundResource
Service Description: Provides a method to create Cloud Dataflow jobs from templates.

This class provides the ability to make remote calls to the backing service through method calls that map to API methods. Sample code to get started:


 // This snippet has been automatically generated and should be regarded as a code template only.
 // It will require modifications to work:
 // - It may require correct/in-range values for request initialization.
 // - It may require specifying regional endpoints when creating the service client as shown in
 // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
 try (TemplatesServiceClient templatesServiceClient = TemplatesServiceClient.create()) {
   CreateJobFromTemplateRequest request =
       CreateJobFromTemplateRequest.newBuilder()
           .setProjectId("projectId-894832108")
           .setJobName("jobName-1438096408")
           .putAllParameters(new HashMap<String, String>())
           .setEnvironment(RuntimeEnvironment.newBuilder().build())
           .setLocation("location1901043637")
           .build();
   Job response = templatesServiceClient.createJobFromTemplate(request);
 }
 

Note: close() needs to be called on the TemplatesServiceClient object to clean up resources such as threads. In the example above, try-with-resources is used, which automatically calls close().

Methods
Method Description Method Variants

CreateJobFromTemplate

Creates a Cloud Dataflow job from a template. Do not enter confidential information when you supply string values using the API.

To create a job, we recommend using `projects.locations.templates.create` with a [regional endpoint] (https://cloud.google.com/dataflow/docs/concepts/regional-endpoints). Using `projects.templates.create` is not recommended, because your job will always start in `us-central1`.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • createJobFromTemplate(CreateJobFromTemplateRequest request)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • createJobFromTemplateCallable()

LaunchTemplate

Launches a template.

To launch a template, we recommend using `projects.locations.templates.launch` with a [regional endpoint] (https://cloud.google.com/dataflow/docs/concepts/regional-endpoints). Using `projects.templates.launch` is not recommended, because jobs launched from the template will always start in `us-central1`.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • launchTemplate(LaunchTemplateRequest request)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • launchTemplateCallable()

GetTemplate

Get the template associated with a template.

To get the template, we recommend using `projects.locations.templates.get` with a [regional endpoint] (https://cloud.google.com/dataflow/docs/concepts/regional-endpoints). Using `projects.templates.get` is not recommended, because only templates that are running in `us-central1` are retrieved.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • getTemplate(GetTemplateRequest request)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • getTemplateCallable()

See the individual methods for example code.

Many parameters require resource names to be formatted in a particular way. To assist with these names, this class includes a format method for each type of name, and additionally a parse method to extract the individual identifiers contained within names that are returned.

This class can be customized by passing in a custom instance of TemplatesServiceSettings to create(). For example:

To customize credentials:


 // This snippet has been automatically generated and should be regarded as a code template only.
 // It will require modifications to work:
 // - It may require correct/in-range values for request initialization.
 // - It may require specifying regional endpoints when creating the service client as shown in
 // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
 TemplatesServiceSettings templatesServiceSettings =
     TemplatesServiceSettings.newBuilder()
         .setCredentialsProvider(FixedCredentialsProvider.create(myCredentials))
         .build();
 TemplatesServiceClient templatesServiceClient =
     TemplatesServiceClient.create(templatesServiceSettings);
 

To customize the endpoint:


 // This snippet has been automatically generated and should be regarded as a code template only.
 // It will require modifications to work:
 // - It may require correct/in-range values for request initialization.
 // - It may require specifying regional endpoints when creating the service client as shown in
 // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
 TemplatesServiceSettings templatesServiceSettings =
     TemplatesServiceSettings.newBuilder().setEndpoint(myEndpoint).build();
 TemplatesServiceClient templatesServiceClient =
     TemplatesServiceClient.create(templatesServiceSettings);
 

To use REST (HTTP1.1/JSON) transport (instead of gRPC) for sending and receiving requests over the wire:


 // This snippet has been automatically generated and should be regarded as a code template only.
 // It will require modifications to work:
 // - It may require correct/in-range values for request initialization.
 // - It may require specifying regional endpoints when creating the service client as shown in
 // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
 TemplatesServiceSettings templatesServiceSettings =
     TemplatesServiceSettings.newHttpJsonBuilder().build();
 TemplatesServiceClient templatesServiceClient =
     TemplatesServiceClient.create(templatesServiceSettings);
 

Please refer to the GitHub repository's samples for more quickstart code snippets.

  • Constructor Details

    • TemplatesServiceClient

      protected TemplatesServiceClient(TemplatesServiceSettings settings) throws IOException
      Constructs an instance of TemplatesServiceClient, using the given settings. This is protected so that it is easy to make a subclass, but otherwise, the static factory methods should be preferred.
      Throws:
      IOException
    • TemplatesServiceClient

      protected TemplatesServiceClient(TemplatesServiceStub stub)
  • Method Details

    • create

      public static final TemplatesServiceClient create() throws IOException
      Constructs an instance of TemplatesServiceClient with default settings.
      Throws:
      IOException
    • create

      public static final TemplatesServiceClient create(TemplatesServiceSettings settings) throws IOException
      Constructs an instance of TemplatesServiceClient, using the given settings. The channels are created based on the settings passed in, or defaults for any settings that are not set.
      Throws:
      IOException
    • create

      public static final TemplatesServiceClient create(TemplatesServiceStub stub)
      Constructs an instance of TemplatesServiceClient, using the given stub for making calls. This is for advanced usage - prefer using create(TemplatesServiceSettings).
    • getSettings

      public final TemplatesServiceSettings getSettings()
    • getStub

      public TemplatesServiceStub getStub()
    • createJobFromTemplate

      public final Job createJobFromTemplate(CreateJobFromTemplateRequest request)
      Creates a Cloud Dataflow job from a template. Do not enter confidential information when you supply string values using the API.

      To create a job, we recommend using `projects.locations.templates.create` with a [regional endpoint] (https://cloud.google.com/dataflow/docs/concepts/regional-endpoints). Using `projects.templates.create` is not recommended, because your job will always start in `us-central1`.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (TemplatesServiceClient templatesServiceClient = TemplatesServiceClient.create()) {
         CreateJobFromTemplateRequest request =
             CreateJobFromTemplateRequest.newBuilder()
                 .setProjectId("projectId-894832108")
                 .setJobName("jobName-1438096408")
                 .putAllParameters(new HashMap<String, String>())
                 .setEnvironment(RuntimeEnvironment.newBuilder().build())
                 .setLocation("location1901043637")
                 .build();
         Job response = templatesServiceClient.createJobFromTemplate(request);
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • createJobFromTemplateCallable

      public final UnaryCallable<CreateJobFromTemplateRequest,Job> createJobFromTemplateCallable()
      Creates a Cloud Dataflow job from a template. Do not enter confidential information when you supply string values using the API.

      To create a job, we recommend using `projects.locations.templates.create` with a [regional endpoint] (https://cloud.google.com/dataflow/docs/concepts/regional-endpoints). Using `projects.templates.create` is not recommended, because your job will always start in `us-central1`.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (TemplatesServiceClient templatesServiceClient = TemplatesServiceClient.create()) {
         CreateJobFromTemplateRequest request =
             CreateJobFromTemplateRequest.newBuilder()
                 .setProjectId("projectId-894832108")
                 .setJobName("jobName-1438096408")
                 .putAllParameters(new HashMap<String, String>())
                 .setEnvironment(RuntimeEnvironment.newBuilder().build())
                 .setLocation("location1901043637")
                 .build();
         ApiFuture<Job> future =
             templatesServiceClient.createJobFromTemplateCallable().futureCall(request);
         // Do something.
         Job response = future.get();
       }
       
    • launchTemplate

      public final LaunchTemplateResponse launchTemplate(LaunchTemplateRequest request)
      Launches a template.

      To launch a template, we recommend using `projects.locations.templates.launch` with a [regional endpoint] (https://cloud.google.com/dataflow/docs/concepts/regional-endpoints). Using `projects.templates.launch` is not recommended, because jobs launched from the template will always start in `us-central1`.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (TemplatesServiceClient templatesServiceClient = TemplatesServiceClient.create()) {
         LaunchTemplateRequest request =
             LaunchTemplateRequest.newBuilder()
                 .setProjectId("projectId-894832108")
                 .setValidateOnly(true)
                 .setLaunchParameters(LaunchTemplateParameters.newBuilder().build())
                 .setLocation("location1901043637")
                 .build();
         LaunchTemplateResponse response = templatesServiceClient.launchTemplate(request);
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • launchTemplateCallable

      public final UnaryCallable<LaunchTemplateRequest,LaunchTemplateResponse> launchTemplateCallable()
      Launches a template.

      To launch a template, we recommend using `projects.locations.templates.launch` with a [regional endpoint] (https://cloud.google.com/dataflow/docs/concepts/regional-endpoints). Using `projects.templates.launch` is not recommended, because jobs launched from the template will always start in `us-central1`.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (TemplatesServiceClient templatesServiceClient = TemplatesServiceClient.create()) {
         LaunchTemplateRequest request =
             LaunchTemplateRequest.newBuilder()
                 .setProjectId("projectId-894832108")
                 .setValidateOnly(true)
                 .setLaunchParameters(LaunchTemplateParameters.newBuilder().build())
                 .setLocation("location1901043637")
                 .build();
         ApiFuture<LaunchTemplateResponse> future =
             templatesServiceClient.launchTemplateCallable().futureCall(request);
         // Do something.
         LaunchTemplateResponse response = future.get();
       }
       
    • getTemplate

      public final GetTemplateResponse getTemplate(GetTemplateRequest request)
      Get the template associated with a template.

      To get the template, we recommend using `projects.locations.templates.get` with a [regional endpoint] (https://cloud.google.com/dataflow/docs/concepts/regional-endpoints). Using `projects.templates.get` is not recommended, because only templates that are running in `us-central1` are retrieved.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (TemplatesServiceClient templatesServiceClient = TemplatesServiceClient.create()) {
         GetTemplateRequest request =
             GetTemplateRequest.newBuilder()
                 .setProjectId("projectId-894832108")
                 .setLocation("location1901043637")
                 .build();
         GetTemplateResponse response = templatesServiceClient.getTemplate(request);
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • getTemplateCallable

      public final UnaryCallable<GetTemplateRequest,GetTemplateResponse> getTemplateCallable()
      Get the template associated with a template.

      To get the template, we recommend using `projects.locations.templates.get` with a [regional endpoint] (https://cloud.google.com/dataflow/docs/concepts/regional-endpoints). Using `projects.templates.get` is not recommended, because only templates that are running in `us-central1` are retrieved.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (TemplatesServiceClient templatesServiceClient = TemplatesServiceClient.create()) {
         GetTemplateRequest request =
             GetTemplateRequest.newBuilder()
                 .setProjectId("projectId-894832108")
                 .setLocation("location1901043637")
                 .build();
         ApiFuture<GetTemplateResponse> future =
             templatesServiceClient.getTemplateCallable().futureCall(request);
         // Do something.
         GetTemplateResponse response = future.get();
       }
       
    • close

      public final void close()
      Specified by:
      close in interface AutoCloseable
    • shutdown

      public void shutdown()
      Specified by:
      shutdown in interface BackgroundResource
    • isShutdown

      public boolean isShutdown()
      Specified by:
      isShutdown in interface BackgroundResource
    • isTerminated

      public boolean isTerminated()
      Specified by:
      isTerminated in interface BackgroundResource
    • shutdownNow

      public void shutdownNow()
      Specified by:
      shutdownNow in interface BackgroundResource
    • awaitTermination

      public boolean awaitTermination(long duration, TimeUnit unit) throws InterruptedException
      Specified by:
      awaitTermination in interface BackgroundResource
      Throws:
      InterruptedException